summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorThijs Kinkhorst <thijs@debian.org>2013-05-05 07:48:49 +0000
committerThijs Kinkhorst <thijs@debian.org>2013-05-05 07:48:49 +0000
commit984f81ffaf2a881ad7bc8658e653dffad982fae8 (patch)
treee9aeab3e78c36a8af5a89298b6a3af9c8a43d62c
parent9a026a5563c63fdd1169013aef61b9ec928af059 (diff)
squeeze=oldstable, wheezy=stable, jessie=testing
git-svn-id: svn+ssh://svn.debian.org/svn/secure-testing@22168 e39458fd-73e7-0310-bf30-c45bca0a0e42
-rw-r--r--Makefile8
-rwxr-xr-xbin/dsa2list2
-rwxr-xr-xbin/gen-DSA6
-rw-r--r--bin/tracker_service.py12
-rw-r--r--data/config.json10
-rw-r--r--lib/python/debian_support.py2
-rw-r--r--lib/python/dist_config.py14
-rw-r--r--lib/python/security_db.py30
8 files changed, 45 insertions, 39 deletions
diff --git a/Makefile b/Makefile
index 5d728903fb..1f78751b6c 100644
--- a/Makefile
+++ b/Makefile
@@ -6,14 +6,14 @@ BUG_LISTS = $(wildcard data/*/list)
# arbitrary at the moment. More architectures can be added later.
MIRROR = http://cdn.debian.net/debian/
-lenny_ARCHS = alpha amd64 arm armel hppa i386 ia64 mips mipsel powerpc s390 sparc
squeeze_ARCHS = amd64 armel i386 ia64 mips mipsel powerpc s390 sparc kfreebsd-i386 kfreebsd-amd64
wheezy_ARCHS = amd64 armel armhf i386 ia64 mips mipsel powerpc s390 s390x sparc kfreebsd-i386 kfreebsd-amd64
+jessie_ARCHS = amd64 armel armhf i386 ia64 mips mipsel powerpc s390 s390x sparc kfreebsd-i386 kfreebsd-amd64
sid_ARCHS = amd64 armel armhf hurd-i386 i386 ia64 kfreebsd-i386 kfreebsd-amd64 mips mipsel powerpc s390 s390x sparc
-OLDSTABLE = lenny
-STABLE = squeeze
-TESTING = wheezy
+OLDSTABLE = squeeze
+STABLE = wheezy
+TESTING = jessie
all:
$(PYTHON) bin/update-db data/security.db
diff --git a/bin/dsa2list b/bin/dsa2list
index bdd8742020..1c9188b277 100755
--- a/bin/dsa2list
+++ b/bin/dsa2list
@@ -70,7 +70,7 @@ dscurl_re = re.compile(r'^\s*(http://\S+\.dsc).*')
# Variants used by "dak new-security-install"
re_date1 = re.compile(r'^([A-Z][a-z][a-z])[a-z]* (\d+), (2\d{3}).*')
release_headline1_re = re.compile(r'^Debian [0-9.]+ \(([a-z]+)\).*')
-release_map = {'stable' : 'squeeze', 'oldstable' : 'lenny'}
+release_map = {'stable' : 'wheezy', 'oldstable' : 'squeeze'}
def process_file(file):
cve_names = {}
diff --git a/bin/gen-DSA b/bin/gen-DSA
index 87c3dca4c5..dcaf31014f 100755
--- a/bin/gen-DSA
+++ b/bin/gen-DSA
@@ -20,9 +20,9 @@
set -e
-OLDSTABLE=lenny
-STABLE=squeeze
-TESTING=wheezy
+OLDSTABLE=squeeze
+STABLE=wheezy
+TESTING=jessie
export LANG=C
diff --git a/bin/tracker_service.py b/bin/tracker_service.py
index 6f913204e1..aae5f4fef1 100644
--- a/bin/tracker_service.py
+++ b/bin/tracker_service.py
@@ -751,13 +751,13 @@ to improve our documentation and procedures, so feedback is welcome.""")])])
return self.page_status_release_unstable_like(
path, params, url,
title='Vulnerable source packages among backports for stable',
- rel='squeeze-backports')
+ rel='wheezy-backports')
def page_status_release_oldstable_backports(self, path, params, url):
return self.page_status_release_unstable_like(
path, params, url,
title='Vulnerable source packages among backports for oldstable',
- rel='lenny-backports')
+ rel='squeeze-backports')
def page_status_dtsa_candidates(self, path, params, url):
bf = BugFilter(params)
@@ -771,11 +771,11 @@ to improve our documentation and procedures, so feedback is welcome.""")])])
(SELECT testing.version_id < stable.version_id
FROM source_packages AS testing, source_packages AS stable
WHERE testing.name = testing_status.package
- AND testing.release = 'wheezy'
+ AND testing.release = 'jessie'
AND testing.subrelease = ''
AND testing.archive = testing_status.section
AND stable.name = testing_status.package
- AND stable.release = 'squeeze'
+ AND stable.release = 'jessie'
AND stable.subrelease = 'security'
AND stable.archive = testing_status.section),
(SELECT range_remote FROM nvd_data
@@ -856,7 +856,7 @@ checker to find out why they have not entered testing yet."""),
old_pkg = ''
old_dsc = ''
last_displayed = ''
- releases = ('sid', 'wheezy', 'squeeze', 'lenny')
+ releases = ('sid', 'jessie', 'wheezy', 'squeeze')
for (pkg_name, bug_name, release, desc) in self.db.cursor().execute(
"""SELECT DISTINCT sp.name, st.bug_name, sp.release,
bugs.description
@@ -901,7 +901,7 @@ checker to find out why they have not entered testing yet."""),
old_dsc = ''
old_name = ''
last_displayed = ''
- releases = ('sid', 'wheezy', 'squeeze', 'lenny')
+ releases = ('sid', 'jessie', 'wheezy', 'squeeze')
for (pkg_name, bug_name, release, desc) in self.db.cursor().execute(
"""SELECT DISTINCT sp.name, st.bug_name, sp.release,
bugs.description
diff --git a/data/config.json b/data/config.json
index 82d6e3649e..974e347f46 100644
--- a/data/config.json
+++ b/data/config.json
@@ -31,20 +31,26 @@
"supported" : ["lenny", "lenny-security"],
"optional" : ["lenny-proposed-updates"]
},
- "release" : "oldstable"
},
"squeeze" : {
"members" : {
"supported" : ["squeeze", "squeeze-security"],
"optional" : ["squeeze-proposed-updates"]
},
- "release" : "stable"
+ "release" : "oldstable"
},
"wheezy" : {
"members" : {
"supported" : ["wheezy", "wheezy-security"],
"optional" : ["wheezy-proposed-updates"]
},
+ "release" : "stable"
+ },
+ "jessie" : {
+ "members" : {
+ "supported" : ["jessie", "jessie-security"],
+ "optional" : ["jessie-proposed-updates"]
+ },
"release" : "testing"
},
"sid" : {
diff --git a/lib/python/debian_support.py b/lib/python/debian_support.py
index 035f8d2097..2c76f2d44d 100644
--- a/lib/python/debian_support.py
+++ b/lib/python/debian_support.py
@@ -193,7 +193,7 @@ class Release(PseudoEnum): pass
def listReleases():
releases = {}
- rels = ("potato", "woody", "sarge", "etch", "lenny", "squeeze", "wheezy", "sid")
+ rels = ("potato", "woody", "sarge", "etch", "lenny", "squeeze", "wheezy", "jessie", "sid")
for r in range(len(rels)):
releases[rels[r]] = Release(rels[r], r)
Release.releases = releases
diff --git a/lib/python/dist_config.py b/lib/python/dist_config.py
index 16c0c54c37..25a9b16e2f 100644
--- a/lib/python/dist_config.py
+++ b/lib/python/dist_config.py
@@ -38,22 +38,22 @@ def apply_config():
# Invoked at the end of the file. Edit this to suit your needs.
squeeze_archs = 'amd64,armel,i386,ia64,kfreebsd-amd64,kfreebsd-i386,mips,mipsel,powerpc,s390,sparc'.split(',')
- lenny_archs = squeeze_archs + ['arm','alpha',]
+ wheezy_archs = squeeze_archs + ['armhf','s390x']
- add_release(name='lenny',
- architectures=lenny_archs,
- )
-
add_release(name='squeeze',
architectures=squeeze_archs,
)
add_release(name='wheezy',
- architectures=squeeze_archs,
+ architectures=wheezy_archs,
+ )
+
+ add_release(name='jessie',
+ architectures=wheezy_archs,
)
add_release(name='sid',
- architectures=squeeze_archs,
+ architectures=wheezy_archs,
)
######################################################################
diff --git a/lib/python/security_db.py b/lib/python/security_db.py
index 969d8e957a..10aa1c80de 100644
--- a/lib/python/security_db.py
+++ b/lib/python/security_db.py
@@ -352,7 +352,7 @@ class DB:
COALESCE((SELECT NOT vulnerable
FROM source_packages AS tsecp, source_package_status AS tsecst
WHERE tsecp.name = sp.name
- AND tsecp.release = 'wheezy' AND tsecp.subrelease = 'security'
+ AND tsecp.release = 'jessie' AND tsecp.subrelease = 'security'
AND tsecp.archive = sp.archive
AND tsecst.bug_name = st.bug_name
AND tsecst.package = tsecp.rowid), 0) AS testing_security_fixed,
@@ -361,13 +361,13 @@ class DB:
(EXISTS (SELECT * FROM package_notes_nodsa AS pnd
WHERE pnd.bug_name = st.bug_name
AND pnd.package = sp.name
- AND pnd.release = 'wheezy')) AS no_dsa
+ AND pnd.release = 'jessie')) AS no_dsa
FROM source_package_status AS st, source_packages AS sp
WHERE st.vulnerable > 0 AND sp.rowid = st.package
- AND sp.release = 'wheezy' AND sp.subrelease = ''
+ AND sp.release = 'jessie' AND sp.subrelease = ''
ORDER BY sp.name, st.urgency, st.bug_name""")
- for (name, nickname) in (('stable', 'squeeze'), ('oldstable', 'lenny'),):
+ for (name, nickname) in (('stable', 'wheezy'), ('oldstable', 'squeeze'),):
cursor.execute(
"""CREATE TEMPORARY VIEW %s_status AS
SELECT DISTINCT sp.name AS package, st.bug_name AS bug,
@@ -924,7 +924,7 @@ class DB:
"""Calculate vulnerable packages.
To each package note, a release-specific vulnerability status
is attached. Currently, only wheezy/testing is processed.
Returns a list strings describing inconsistencies.
"""
@@ -940,7 +940,7 @@ class DB:
# The following does not work because stable->security ->
# testing -> unstable propagation is no longer available.
if False:
# Ignore wheezy/testing because stable issues may be
# fast-tracked into testing, bypassing unstable.
for (bug_name, pkg_name, rel, unstable_ver, rel_ver) \
in list(cursor.execute(
@@ -948,7 +948,7 @@ class DB:
a.fixed_version, b.fixed_version
FROM package_notes a, package_notes b
WHERE a.bug_name = b.bug_name AND a.package = b.package
- AND a.release = '' AND b.release NOT IN ('', 'wheezy')
+ AND a.release = '' AND b.release NOT IN ('', 'jessie')
AND a.fixed_version IS NOT NULL
AND a.fixed_version_id < b.fixed_version_id""")):
b = bugs.BugFromDB(cursor, bug_name)
@@ -1064,9 +1064,9 @@ class DB:
"SELECT name FROM bugs WHERE NOT not_for_us"):
self._calcUnstable(c, bug_name)
- self._calcTesting(c, bug_name, 'testing', 'wheezy')
- self._calcTesting(c, bug_name, 'stable', 'squeeze')
- self._calcTesting(c, bug_name, 'oldstable', 'lenny')
+ self._calcTesting(c, bug_name, 'testing', 'jessie')
+ self._calcTesting(c, bug_name, 'stable', 'wheezy')
+ self._calcTesting(c, bug_name, 'oldstable', 'squeeze')
return result
@@ -1511,7 +1511,7 @@ class DB:
store_value('release/1/' + release, '\n'.join(result))
- for release in ('sid', 'lenny', 'squeeze', 'wheezy'):
+ for release in ('sid', 'squeeze', 'wheezy', 'jessie'):
gen_release(release)
result = result_start
@@ -1524,7 +1524,7 @@ class DB:
def calculateDebsecan(self):
"""Calculate all debsecan data."""
- for release in ('', 'lenny', 'squeeze', 'wheezy'):
+ for release in ('', 'squeeze', 'wheezy', 'jessie'):
self.calculateDebsecan0(release)
self.calculateDebsecan1()
@@ -1561,7 +1561,7 @@ class DB:
"""SELECT string_list(release) AS releases, version
FROM (SELECT release, version FROM source_packages
WHERE name = ?
AND release IN ('lenny', 'squeeze', 'wheezy', 'sid')
ORDER BY release_to_number(release))
GROUP BY version""", (pkg,)):
yield releases.split(', '), version
@@ -1616,7 +1616,7 @@ class DB:
p.version AS version, s.vulnerable AS vulnerable
FROM source_package_status AS s, source_packages AS p
WHERE s.bug_name = ? AND p.rowid = s.package
AND release in ('lenny', 'squeeze', 'wheezy', 'sid')
ORDER BY release_to_number(p.release), p.subrelease)
GROUP BY package, version, vulnerable
ORDER BY package, version COLLATE version""",
@@ -1666,7 +1666,7 @@ class DB:
st.urgency = 'unimportant' OR NOT vulnerable AS unimportant
FROM source_packages AS sp, source_package_status AS st, bugs
WHERE sp.name = ?
AND sp.release IN ('lenny', 'squeeze', 'wheezy', 'sid')
AND sp.subrelease <> 'security'
AND st.package = sp.rowid
AND bugs.name = st.bug_name
@@ -924,7 +924,7 @@ class DB:
"""Calculate vulnerable packages.
To each package note, a release-specific vulnerability status
- is attached. Currently, only wheezy/testing is processed.
+ is attached. Currently, only jessie/testing is processed.
Returns a list strings describing inconsistencies.
"""
@@ -940,7 +940,7 @@ class DB:
# testing -> unstable propagation is no longer available.
if False:
- # Ignore wheezy/testing because stable issues may be
+ # Ignore jessie/testing because stable issues may be
# fast-tracked into testing, bypassing unstable.
for (bug_name, pkg_name, rel, unstable_ver, rel_ver) \
@@ -1561,7 +1561,7 @@ class DB:
FROM (SELECT release, version FROM source_packages
WHERE name = ?
- AND release IN ('lenny', 'squeeze', 'wheezy', 'sid')
+ AND release IN ('squeeze', 'wheezy', 'jessie', 'sid')
ORDER BY release_to_number(release))
GROUP BY version""", (pkg,)):
@@ -1616,7 +1616,7 @@ class DB:
FROM source_package_status AS s, source_packages AS p
WHERE s.bug_name = ? AND p.rowid = s.package
- AND release in ('lenny', 'squeeze', 'wheezy', 'sid')
+ AND release in ('squeeze', 'wheezy', 'jessie', 'sid')
ORDER BY release_to_number(p.release), p.subrelease)
GROUP BY package, version, vulnerable
@@ -1666,7 +1666,7 @@ class DB:
FROM source_packages AS sp, source_package_status AS st, bugs
WHERE sp.name = ?
- AND sp.release IN ('lenny', 'squeeze', 'wheezy', 'sid')
+ AND sp.release IN ('squeeze', 'wheezy', 'jessie', 'sid')
AND sp.subrelease <> 'security'
AND st.package = sp.rowid

© 2014-2024 Faster IT GmbH | imprint | privacy policy